Struct libits_client::reception::exchange::map_extended_message::Connection
source · pub struct Connection {
pub id: Option<u64>,
pub intersection_id: u64,
pub lane_id: u64,
pub action: Action,
pub caution: Option<bool>,
}Expand description
Represents a connection between lanes
Fields
id: Option<u64>intersection_id: u64intersection_id of the connected lane
Value is 0 if the connected lane is in the same intersection
lane_id: u64lane_id of the connected lane
Value is 0 if the connected lane is unknown, but the action is still possible
action: ActionTurn direction leading to the connected lane
caution: Option<bool>True if taking this pas has to be executed with caution (e.g. pedestrian crossing on a right or left turn)