pub struct MAPExtendedMessage {
    pub protocol_version: u16,
    pub id: u64,
    pub timestamp: Option<u64>,
    pub sending_station_id: Option<u64>,
    pub region: Option<u64>,
    pub revision: Option<u16>,
    pub lanes: Vec<Lane>,
}
MAPEM representation

MAP (topology) Extended Message

See also:

Fields

protocol_version: u16id: u64timestamp: Option<u64>

Reference time of the geometry present in the message

sending_station_id: Option<u64>region: Option<u64>revision: Option<u16>lanes: Vec<Lane>

List of the lanes in the intersection

Implementations

source

impl MAPExtendedMessage

source

pub fn get_lane_from_position( &self, position: &ReferencePosition ) -> Option<&Lane>

Lookup the existing lanes to find the one the position is in or close to

FIXME this requires unit tests and consolidation