pub struct ReferencePosition {
    pub latitude: i32,
    pub longitude: i32,
    pub altitude: i32,
}

Fields

latitude: i32longitude: i32altitude: i32

Implementations

source

impl ReferencePosition

source

pub fn get_distance(&self, other: &ReferencePosition) -> u32

source

pub fn get_heading(&self, other: &ReferencePosition) -> u16

source

pub fn get_destination(&self, distance: f64, bearing: f64) -> Self

source

pub fn as_geo_point(&self) -> Point<f64>

source

pub fn get_offset_destination( &self, easting_offset: f64, northing_offset: f64 ) -> Self

source

pub fn to_enu(&self, anchor: &ReferencePosition) -> (f64, f64, f64)

Converts this position to its East North Up (ENU) coordinates from the reference position anchor

Computation is done by first converting the geodetic coordinates (lat, lon, alt) of both this point and the reference point to ECEF coordinates Then the ENU computation can be done

source

pub fn to_ecef(&self) -> (f64, f64, f64)

Returns the corresponding Earth Centered, Earth Fixed coordinates for this position